@@ -1,23 +1,21 @@
-package Pod::Simple::Checker;
 
 # A quite dimwitted pod2plaintext that need only know how to format whatever
 # text comes out of Pod::BlackBox's _gen_errata
 
-require 5.006;
+require 5;
+package Pod::Simple::Checker;
 use strict;
-use warnings;
 use Carp ();
 use Pod::Simple::Methody ();
 use Pod::Simple ();
-
+use vars qw( @ISA $VERSION );
+$VERSION = '3.11';
+@ISA = ('Pod::Simple::Methody');
 BEGIN { *DEBUG = defined(&Pod::Simple::DEBUG)
           ? \&Pod::Simple::DEBUG
           : sub() {0}
       }
 
-our $VERSION = '3.33_06';
-our @ISA     = ('Pod::Simple::Methody');
-
 use Text::Wrap 98.112902 (); # was 2001.0131, but I don't think we need that
 $Text::Wrap::wrap = 'overflow';
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -93,9 +91,9 @@ sub emit_par {
   my $indent = ' ' x ( 2 * $self->{'Indent'} + ($tweak_indent||0) );
    # Yes, 'STRING' x NEGATIVE gives '', same as 'STRING' x 0
 
-  $self->{'Thispara'} =~ s/$Pod::Simple::shy//g;
+  $self->{'Thispara'} =~ tr{\xAD}{}d if Pod::Simple::ASCII;
   my $out = Text::Wrap::wrap($indent, $indent, $self->{'Thispara'} .= "\n");
-  $out =~ s/$Pod::Simple::nbsp/ /g;
+  $out =~ tr{\xA0}{ } if Pod::Simple::ASCII;
   print {$self->{'output_fh'}} $out,
     #"\n"
   ;
@@ -109,8 +107,10 @@ sub emit_par {
 sub end_Verbatim  {
   return unless $_[0]{'Errata_seen'};
   my $self = shift;
-  $self->{'Thispara'} =~ s/$Pod::Simple::nbsp/ /g;
-  $self->{'Thispara'} =~ s/$Pod::Simple::shy//g;
+  if(Pod::Simple::ASCII) {
+    $self->{'Thispara'} =~ tr{\xA0}{ };
+    $self->{'Thispara'} =~ tr{\xAD}{}d;
+  }
 
   my $i = ' ' x ( 2 * $self->{'Indent'} + 4);
   
@@ -159,15 +159,15 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
