@@ -1,10 +1,9 @@
+
+require 5;
 package Pod::Simple::Debug;
-
-require 5.006;
 use strict;
-use warnings;
-
-our $VERSION = '3.33_06';
+use vars qw($VERSION );
+$VERSION = '3.11';
 
 sub import {
   my($value,$variable);
@@ -49,10 +48,10 @@ sub import {
     # make a not-really-constant
     *Pod::Simple::DEBUG = sub () { $$variable } ;
     $$variable = $value;
-    print STDERR "# Starting Pod::Simple::DEBUG = non-constant $variable with val $value\n";
+    print "# Starting Pod::Simple::DEBUG = non-constant $variable with val $value\n";
   } else {
     *Pod::Simple::DEBUG = eval " sub () { $value } ";
-    print STDERR "# Starting Pod::Simple::DEBUG = $value\n";
+    print "# Starting Pod::Simple::DEBUG = $value\n";
   }
   
   require Pod::Simple;
@@ -98,7 +97,7 @@ Note that you should load this module I<before> loading Pod::Simple (or
 any Pod::Simple-based class).  If you try loading Pod::Simple::Debug
 after &Pod::Simple::DEBUG is already defined, Pod::Simple::Debug will
 throw a fatal error to the effect that
-"It's too late to call Pod::Simple::Debug".
+"it's s too late to call Pod::Simple::Debug".
 
 Note that the C<use Pod::Simple::Debug (\$x, I<somenum>)> mode will make
 Pod::Simple (et al) run rather slower, since &Pod::Simple::DEBUG won't
@@ -142,15 +141,15 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
