@@ -1,14 +1,13 @@
+
+require 5;
 package Pod::Simple::DumpAsText;
-
-require 5.006;
-use strict;
-use warnings;
-use Carp ();
+$VERSION = '3.11';
 use Pod::Simple ();
+BEGIN {@ISA = ('Pod::Simple')}
 
-our $VERSION = '3.33_06';
-our @ISA     = ('Pod::Simple');
+use strict;
 
+use Carp ();
 
 BEGIN { *DEBUG = \&Pod::Simple::DEBUG unless defined &DEBUG }
 
@@ -17,7 +16,6 @@ sub new {
   my $new = $self->SUPER::new(@_);
   $new->{'output_fh'} ||= *STDOUT{IO};
   $new->accept_codes('VerbatimFormatted');
-  $new->keep_encoding_directive(1);
   return $new;
 }
 
@@ -27,7 +25,7 @@ sub _handle_element_start {
   # ($self, $element_name, $attr_hash_r)
   my $fh = $_[0]{'output_fh'};
   my($key, $value);
-  DEBUG and print STDERR "++ $_[1]\n";
+  DEBUG and print "++ $_[1]\n";
   
   print $fh   '  ' x ($_[0]{'indent'} || 0),  "++", $_[1], "\n";
   $_[0]{'indent'}++;
@@ -44,7 +42,7 @@ sub _handle_element_start {
 }
 
 sub _handle_text {
-  DEBUG and print STDERR "== \"$_[1]\"\n";
+  DEBUG and print "== \"$_[1]\"\n";
   
   if(length $_[1]) {
     my $indent = '  ' x $_[0]{'indent'};
@@ -55,7 +53,7 @@ sub _handle_text {
          [^\n]{55}         # Snare some characters from a line
          [^\n\ ]{0,50}     #  and finish any current word
         )
-        \ {1,10}(?!\n)     # capture some spaces not at line-end
+        \x20{1,10}(?!\n)   # capture some spaces not at line-end
        /$1"\n$indent . "/gx     # => line-break here
     ;
     
@@ -65,7 +63,7 @@ sub _handle_text {
 }
 
 sub _handle_element_end {
-  DEBUG and print STDERR "-- $_[1]\n";
+  DEBUG and print "-- $_[1]\n";
   print {$_[0]{'output_fh'}}
    '  ' x --$_[0]{'indent'}, "--", $_[1], "\n";
   return;
@@ -120,15 +118,15 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
