@@ -1,15 +1,13 @@
+
+require 5;
 package Pod::Simple::DumpAsXML;
-
-require 5.006;
-use strict;
-use warnings;
+$VERSION = '3.11';
 use Pod::Simple ();
+BEGIN {@ISA = ('Pod::Simple')}
+
+use strict;
+
 use Carp ();
-use Text::Wrap qw(wrap);
-
-our $VERSION = '3.33_06';
-our @ISA     = ('Pod::Simple');
-
 
 BEGIN { *DEBUG = \&Pod::Simple::DEBUG unless defined &DEBUG }
 
@@ -18,7 +16,6 @@ sub new {
   my $new = $self->SUPER::new(@_);
   $new->{'output_fh'} ||= *STDOUT{IO};
   $new->accept_codes('VerbatimFormatted');
-  $new->keep_encoding_directive(1);
   return $new;
 }
 
@@ -28,7 +25,7 @@ sub _handle_element_start {
   # ($self, $element_name, $attr_hash_r)
   my $fh = $_[0]{'output_fh'};
   my($key, $value);
-  DEBUG and print STDERR "++ $_[1]\n";
+  DEBUG and print "++ $_[1]\n";
   
   print $fh   '  ' x ($_[0]{'indent'} || 0),  "<", $_[1];
 
@@ -47,20 +44,27 @@ sub _handle_element_start {
 }
 
 sub _handle_text {
-  DEBUG and print STDERR "== \"$_[1]\"\n";
+  DEBUG and print "== \"$_[1]\"\n";
   if(length $_[1]) {
     my $indent = '  ' x $_[0]{'indent'};
     my $text = $_[1];
     _xml_escape($text);
-    local $Text::Wrap::huge = 'overflow';
-    $text = wrap('', $indent, $text);
+    $text =~  # A not-totally-brilliant wrapping algorithm:
+      s/(
+         [^\n]{55}         # Snare some characters from a line
+         [^\n\ ]{0,50}     #  and finish any current word
+        )
+        \x20{1,10}(?!\n)   # capture some spaces not at line-end
+       /$1\n$indent/gx     # => line-break here
+    ;
+    
     print {$_[0]{'output_fh'}} $indent, $text, "\n";
   }
   return;
 }
 
 sub _handle_element_end {
-  DEBUG and print STDERR "-- $_[1]\n";
+  DEBUG and print "-- $_[1]\n";
   print {$_[0]{'output_fh'}}
    '  ' x --$_[0]{'indent'}, "</", $_[1], ">\n";
   return;
@@ -71,13 +75,11 @@ sub _handle_element_end {
 sub _xml_escape {
   foreach my $x (@_) {
     # Escape things very cautiously:
-    if ($] ge 5.007_003) {
-      $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/'&#'.(utf8::native_to_unicode(ord($1))).';'/eg;
-    } else { # Is broken for non-ASCII platforms on early perls
-      $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/'&#'.(ord($1)).';'/eg;
-    }
+    $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/'&#'.(ord($1)).';'/eg;
     # Yes, stipulate the list without a range, so that this can work right on
     #  all charsets that this module happens to run under.
+    # Altho, hmm, what about that ord?  Presumably that won't work right
+    #  under non-ASCII charsets.  Something should be done about that.
   }
   return;
 }
@@ -112,7 +114,7 @@ L<Pod::Simple>.
 L<Pod::Simple::XMLOutStream> is rather like this class.
 Pod::Simple::XMLOutStream's output is space-padded in a way
 that's better for sending to an XML processor (that is, it has
-no ignorable whitespace). But
+no ignoreable whitespace). But
 Pod::Simple::DumpAsXML's output is much more human-readable, being
 (more-or-less) one token per line, with line-wrapping.
 
@@ -131,15 +133,15 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
