@@ -5,7 +5,7 @@ use strict;
 use vars qw( $VERSION $HTML_RENDER_CLASS $HTML_EXTENSION
  $CSS $JAVASCRIPT $SLEEPY $SEARCH_CLASS @ISA
 );
-$VERSION = '3.01';
+$VERSION = '3.11';
 @ISA = ();  # Yup, we're NOT a subclass of Pod::Simple::HTML!
 
 # TODO: nocontents stylesheets. Strike some of the color variations?
@@ -37,6 +37,7 @@ $HTML_RENDER_CLASS ||= "Pod::Simple::HTML";
 Pod::Simple::_accessorize( __PACKAGE__,
  'verbose', # how verbose to be during batch conversion
  'html_render_class', # what class to use to render
+ 'search_class', # what to use to search for POD documents
  'contents_file', # If set, should be the name of a file (in current directory)
                   # to write the list of all modules to
  'index', # will set $htmlpage->index(...) to this (true or false)
@@ -71,6 +72,7 @@ sub go {
 sub new {
   my $new = bless {}, ref($_[0]) || $_[0];
   $new->html_render_class($HTML_RENDER_CLASS);
+  $new->search_class($SEARCH_CLASS);
   $new->verbose(1 + DEBUG);
   $new->_contents([]);
   
@@ -246,9 +248,9 @@ sub _do_one_batch_conversion {
   }
 
   # Give each class a chance to init the converter:
-  
   $page->batch_mode_page_object_init($self, $module, $infile, $outfile, $depth)
    if $page->can('batch_mode_page_object_init');
+  # Init for the index (TOC), too.
   $self->batch_mode_page_object_init($page, $module, $infile, $outfile, $depth)
    if $self->can('batch_mode_page_object_init');
     
@@ -532,7 +534,7 @@ sub modnames2paths { # return a hashref mapping modulenames => paths
 
   my $m2p;
   {
-    my $search = $SEARCH_CLASS->new;
+    my $search = $self->search_class->new;
     DEBUG and print "Searching via $search\n";
     $search->verbose(1) if DEBUG > 10;
     $search->progress( $self->progress->copy->goal(0) ) if $self->progress;
@@ -607,7 +609,7 @@ sub _spray_css {
     my $url = $chunk->[0];
     my $outfile;
     if( ref($chunk->[-1]) and $url =~ m{^(_[-a-z0-9_]+\.css$)} ) {
-      $outfile = $self->filespecsys->catfile( $outdir, $1 );
+      $outfile = $self->filespecsys->catfile( $outdir, "$1" );
       DEBUG > 5 and print "Noting $$chunk[0] as a file I'll create.\n";
     } else {
       DEBUG > 5 and print "OK, noting $$chunk[0] as an external CSS.\n";
@@ -681,20 +683,16 @@ sub _gen_css_wad {
    #  010=white_with_green_on_black
    #  011=white_with_blue_on_black
    #  100=white_with_red_on_black
-  
-   qw[
-    110n=black_with_blue_on_white
-    010n=black_with_magenta_on_white
-    100n=black_with_cyan_on_white
-
-    101=white_with_purple_on_black
-    001=white_with_navy_blue_on_black
-
-    010a=grey_with_green_on_black
-    010b=white_with_green_on_grey
-    101an=black_with_green_on_grey
-    101bn=grey_with_green_on_white
-  ]) {
+    '110n=blkbluw',  # black_with_blue_on_white
+    '010n=blkmagw',  # black_with_magenta_on_white
+    '100n=blkcynw',  # black_with_cyan_on_white
+    '101=whtprpk',   # white_with_purple_on_black
+    '001=whtnavk',   # white_with_navy_blue_on_black
+    '010a=grygrnk',  # grey_with_green_on_black
+    '010b=whtgrng',  # white_with_green_on_grey
+    '101an=blkgrng', # black_with_green_on_grey
+    '101bn=grygrnw', # grey_with_green_on_white
+  ) {
 
     my $outname = $variation;
     my($flipmode, @swap) = ( ($4 || ''), $1,$2,$3)
@@ -724,11 +722,13 @@ sub _gen_css_wad {
   }
 
   # Now a few indexless variations:
-  foreach my $variation (qw[
-    black_with_blue_on_white  white_with_purple_on_black
-    white_with_green_on_grey  grey_with_green_on_white
-  ]) {
-    my $outname = "indexless_$variation";
+  foreach my $variation (
+      'blkbluw', # black_with_blue_on_white
+      'whtpurk', # white_with_purple_on_black
+      'whtgrng', # white_with_green_on_grey
+      'grygrnw', # grey_with_green_on_white
+  ) {
+    my $outname = "$variation\_";
     my $this_css = join "\n",
       "/* This file is autogenerated.  Do not edit.  $outname */\n",
       "\@import url(\"./_$variation.css\");",
@@ -737,7 +737,7 @@ sub _gen_css_wad {
     ;
     my $name = $outname;    
     $name =~ tr/-_/  /;
-    $self->add_css( "_$outname.css", 0, $name, 0, 0, \$this_css);
+    $self->add_css( "$outname.css", 0, $name, 0, 0, \$this_css);
   }
 
   return;
@@ -772,7 +772,7 @@ sub _spray_javascript {
     my $outfile;
     
     if( ref($script->[-1]) and $url =~ m{^(_[-a-z0-9_]+\.js$)} ) {
-      $outfile = $self->filespecsys->catfile( $outdir, $1 );
+      $outfile = $self->filespecsys->catfile( $outdir, "$1" );
       DEBUG > 5 and print "Noting $$script[0] as a file I'll create.\n";
     } else {
       DEBUG > 5 and print "OK, noting $$script[0] as an external JavaScript.\n";
@@ -875,7 +875,7 @@ $CSS = <<'EOCSS';
   }
 
   body.pod h1, body.pod h2, body.pod h3, body.pod h4  {
-    font-family: Tahoma, Verdana, Helvetica, Arial, "sans-serif";
+    font-family: Tahoma, Verdana, Helvetica, Arial, sans-serif;
     font-weight: normal;
     margin-top: 1.2em;
     margin-bottom: .1em;
@@ -894,7 +894,7 @@ $CSS = <<'EOCSS';
   p.backlinktop + h4 { border-top: none; margin-top: 0em;  }
 
   body.pod dt {
-    font-size: 105%; # just a wee bit more than normal
+    font-size: 105%; /* just a wee bit more than normal */
   }
 
   .indexgroup { font-size: 80%; }
@@ -926,7 +926,7 @@ $CSS = <<'EOCSS';
     margin-left: 1em;
     margin-right: 1em;
     text-indent: -.9em;
-    font-family: Tahoma, Verdana, Helvetica, Arial, "sans-serif";
+    font-family: Tahoma, Verdana, Helvetica, Arial, sans-serif;
     font-weight: normal;
     border-top:    thin solid #fff;
     border-bottom: thin solid #fff;
@@ -934,7 +934,7 @@ $CSS = <<'EOCSS';
   }
 
   dl.superindex > dt  {
-    font-family: Tahoma, Verdana, Helvetica, Arial, "sans-serif";
+    font-family: Tahoma, Verdana, Helvetica, Arial, sans-serif;
     font-weight: normal;
     font-size: 90%;
     margin-top: .45em;
@@ -1275,6 +1275,14 @@ TODO
 =item $batchconv->html_render_class( I<classname> );
 
 This sets what class is used for rendering the files.
+The default is "Pod::Simple::HTML".  If you set it to something else,
+it should probably be a subclass of Pod::Simple::HTML, and you should
+C<require> or C<use> that class so that's it's loaded before
+Pod::Simple::HTMLBatch tries loading it.
+
+=item $batchconv->search_class( I<classname> );
+
+This sets what class is used for searching for the files.
 The default is "Pod::Simple::Search".  If you set it to something else,
 it should probably be a subclass of Pod::Simple::Search, and you should
 C<require> or C<use> that class so that's it's loaded before
@@ -1300,6 +1308,8 @@ TODO
     $page->batch_mode_page_object_init($self, $module, $infile, $outfile, $depth)
   or maybe override
     $batchconv->batch_mode_page_object_init($page, $module, $infile, $outfile, $depth)
+  subclass Pod::Simple::Search and set $batchconv->search_class to
+    that classname
 
 
 
@@ -1318,12 +1328,22 @@ you're looking for.
 
 L<Pod::Simple>, L<Pod::Simple::HTMLBatch>, L<perlpod>, L<perlpodspec>
 
+=head1 SUPPORT
 
+Questions or discussion about POD and Pod::Simple should be sent to the
+pod-people@perl.org mail list. Send an empty email to
+pod-people-subscribe@perl.org to subscribe.
 
+This module is managed in an open GitHub repository,
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
+
+Patches against Pod::Simple are welcome. Please send bug reports to
+<bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2004 Sean M. Burke.  All rights reserved.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -1334,9 +1354,19 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Sean M. Burke C<sburke@cpan.org>
+Pod::Simple was created by Sean M. Burke <sburke@cpan.org>.
+But don't bother him, he's retired.
+
+Pod::Simple is maintained by:
+
+=over
+
+=item * Allison Randal C<allison@perl.org>
+
+=item * Hans Dieter Pearcey C<hdp@cpan.org>
+
+=item * David E. Wheeler C<dwheeler@cpan.org>
+
+=back
 
 =cut
-
-
-
