@@ -1,12 +1,14 @@
+
+require 5;
 package Pod::Simple::LinkSection;
-
-require 5.006;
-use strict;
-use warnings;
-use Pod::Simple::BlackBox;
   # Based somewhat dimly on Array::Autojoin
+use vars qw($VERSION );
+$VERSION = '3.11';
 
-our $VERSION = '3.33_06';
+use strict;
+use Pod::Simple::BlackBox;
+use vars qw($VERSION );
+$VERSION = '3.11';
 
 use overload( # So it'll stringify nice
   '""'   => \&Pod::Simple::BlackBox::stringify_lol,
@@ -16,8 +18,6 @@ use overload( # So it'll stringify nice
   'fallback' => 1,         # turn on cleverness
 );
 
-no warnings 'redefine';
-
 sub tack_on {
   $_[0] = ['', {}, "$_[0]" ];
   return $_[0][2] .= $_[1];
@@ -114,7 +114,7 @@ Output:
                           ], 'Pod::Simple::LinkSection' ),
                    'baz'
                  ], 'Pod::Simple::LinkSection' );
-
+  
 But stringify it and you get just the text content:
 
   % perl -MData::Dumper -e
@@ -137,15 +137,15 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2004 Sean M. Burke.
+Copyright (c) 2004 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
