@@ -1,10 +1,8 @@
+
+require 5;
 package Pod::Simple::Progress;
-
-require 5.006;
+$VERSION = '3.11';
 use strict;
-use warnings;
-
-our $VERSION = '3.33_06';
 
 # Objects of this class are used for noting progress of an
 #  operation every so often.  Messages delivered more often than that
