@@ -1,12 +1,11 @@
+
+require 5;
 package Pod::Simple::PullParserTextToken;
-
-require 5.006;
-use strict;
-use warnings;
 use Pod::Simple::PullParserToken ();
-
-our @ISA     = ('Pod::Simple::PullParserToken');
-our $VERSION = '3.33_06';
+use strict;
+use vars qw(@ISA $VERSION);
+@ISA = ('Pod::Simple::PullParserToken');
+$VERSION = '3.11';
 
 sub new {  # Class->new(text);
   my $class = shift;
@@ -62,21 +61,15 @@ as calling $token->text would do.
 Or, if you want to alter the value, you can even do things like this:
 
   for ( ${  $token->text_r  } ) {  # Aliases it with $_ !!
-
+  
     s/ The / the /g; # just for example
-
+    
     if( 'A' eq chr(65) ) {  # (if in an ASCII world)
       tr/\xA0/ /;
       tr/\xAD//d;
     }
-
+    
     ...or however you want to alter the value...
-    (Note that starting with Perl v5.8, you can use, e.g.,
-
-        my $nbsp = chr utf8::unicode_to_native(0xA0);
-        s/$nbsp/ /g;
-
-    to handle the above regardless if it's an ASCII world or not)
   }
 
 =back
@@ -98,15 +91,15 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
