@@ -1,12 +1,10 @@
+
+require 5;
 package Pod::Simple::PullParserToken;
-
-require 5.006;
+ # Base class for tokens gotten from Pod::Simple::PullParser's $parser->get_token
+@ISA = ();
+$VERSION = '3.11';
 use strict;
-use warnings;
-# Base class for tokens gotten from Pod::Simple::PullParser's $parser->get_token
-
-our @ISA     = ();
-our $VERSION = '3.33_06';
 
 sub new {  # Class->new('type', stuff...);  ## Overridden in derived classes anyway
   my $class = shift;
@@ -52,16 +50,16 @@ Given a $parser that's an object of class Pod::Simple::PullParser
 (or a subclass)...
 
   while(my $token = $parser->get_token) {
-    $DEBUG and print STDERR "Token: ", $token->dump, "\n";
+    $DEBUG and print "Token: ", $token->dump, "\n";
     if($token->is_start) {
       ...access $token->tagname, $token->attr, etc...
 
     } elsif($token->is_text) {
       ...access $token->text, $token->text_r, etc...
-
+    
     } elsif($token->is_end) {
       ...access $token->tagname...
-
+    
     }
   }
 
@@ -106,7 +104,7 @@ This returns a handy stringified value of this object.  This
 is useful for debugging, as in:
 
   while(my $token = $parser->get_token) {
-    $DEBUG and print STDERR "Token: ", $token->dump, "\n";
+    $DEBUG and print "Token: ", $token->dump, "\n";
     ...
   }
 
@@ -128,15 +126,15 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
