@@ -1,15 +1,14 @@
-package Pod::Simple::SimpleTree;
 
-require 5.006;
+
+require 5;
+package Pod::Simple::SimpleTree;
 use strict;
-use warnings;
 use Carp ();
 use Pod::Simple ();
-
-our $VERSION = '3.33_06';
-our @ISA     = ('Pod::Simple');
-
+use vars qw( $ATTR_PAD @ISA $VERSION $SORT_ATTRS);
+$VERSION = '3.11';
 BEGIN {
+  @ISA = ('Pod::Simple');
   *DEBUG = \&Pod::Simple::DEBUG unless defined &DEBUG;
 }
 
@@ -20,31 +19,31 @@ __PACKAGE__->_accessorize(
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 sub _handle_element_start { # self, tagname, attrhash
-  DEBUG > 2 and print STDERR "Handling $_[1] start-event\n";
+  DEBUG > 2 and print "Handling $_[1] start-event\n";
   my $x = [$_[1], $_[2]];
   if($_[0]{'_currpos'}) {
     push    @{ $_[0]{'_currpos'}[0] }, $x; # insert in parent's child-list
     unshift @{ $_[0]{'_currpos'} },    $x; # prefix to stack
   } else {
-    DEBUG and print STDERR " And oo, it gets to be root!\n";
+    DEBUG and print " And oo, it gets to be root!\n";
     $_[0]{'_currpos'} = [   $_[0]{'root'} = $x   ];
       # first event!  set to stack, and set as root.
   }
-  DEBUG > 3 and print STDERR "Stack is now: ",
+  DEBUG > 3 and print "Stack is now: ",
     join(">", map $_->[0], @{$_[0]{'_currpos'}}), "\n";
   return;
 }
 
 sub _handle_element_end { # self, tagname
-  DEBUG > 2 and print STDERR "Handling $_[1] end-event\n";
+  DEBUG > 2 and print "Handling $_[1] end-event\n";
   shift @{$_[0]{'_currpos'}};
-  DEBUG > 3 and print STDERR "Stack is now: ",
+  DEBUG > 3 and print "Stack is now: ",
     join(">", map $_->[0], @{$_[0]{'_currpos'}}), "\n";
   return;
 }
 
 sub _handle_text { # self, text
-  DEBUG > 2 and print STDERR "Handling $_[1] text-event\n";
+  DEBUG > 2 and print "Handling $_[1] text-event\n";
   push @{ $_[0]{'_currpos'}[0] }, $_[1];
   return;
 }
@@ -52,7 +51,7 @@ sub _handle_text { # self, text
 
 # A bit of evil from the black box...  please avert your eyes, kind souls.
 sub _traverse_treelet_bit {
-  DEBUG > 2 and print STDERR "Handling $_[1] paragraph event\n";
+  DEBUG > 2 and print "Handling $_[1] paragraph event\n";
   my $self = shift;
   push @{ $self->{'_currpos'}[0] }, [@_];
   return;
@@ -68,15 +67,15 @@ Pod::Simple::SimpleTree -- parse Pod into a simple parse tree
 =head1 SYNOPSIS
 
   % cat ptest.pod
-
+  
   =head1 PIE
-
+  
   I like B<pie>!
-
+  
   % perl -MPod::Simple::SimpleTree -MData::Dumper -e \
      "print Dumper(Pod::Simple::SimpleTree->new->parse_file(shift)->root)" \
      ptest.pod
-
+  
   $VAR1 = [
             'Document',
             { 'start_line' => 1 },
@@ -122,7 +121,7 @@ the form: C<[ I<elementname>, \%attributes, I<...subnodes...> ]>.
 See the example tree dump in the Synopsis, above.
 
 Every text node in the tree is represented by a simple (non-ref)
-string scalar.  So you can test C<ref($node)> to see whether you have
+string scalar.  So you can test C<ref($node)> to see whather you have
 an element node or just a text node.
 
 The top node in the tree is C<[ 'Document', \%attributes,
@@ -144,15 +143,15 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
