@@ -1,13 +1,13 @@
-package Pod::Simple::TextContent;
 
-require 5.006;
+
+require 5;
+package Pod::Simple::TextContent;
 use strict;
-use warnings;
 use Carp ();
 use Pod::Simple ();
-
-our $VERSION = '3.33_06';
-our @ISA     = ('Pod::Simple');
+use vars qw( @ISA $VERSION );
+$VERSION = '3.11';
+@ISA = ('Pod::Simple');
 
 sub new {
   my $self = shift;
@@ -25,9 +25,10 @@ sub _handle_element_start {
 }
 
 sub _handle_text {
-  no warnings 'once';
-  $_[1] =~ s/$Pod::Simple::shy//g;
-  $_[1] =~ s/$Pod::Simple::nbsp/ /g;
+  if( chr(65) eq 'A' ) {     # in ASCIIworld
+    $_[1] =~ tr/\xAD//d;
+    $_[1] =~ tr/\xA0/ /;
+  }
   print {$_[0]{'output_fh'}} $_[1];
   return;
 }
@@ -74,15 +75,15 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
