@@ -1,12 +1,10 @@
-package Pod::Simple::TiedOutFH;
 
-require 5.006;
 use strict;
-use warnings;
+package Pod::Simple::TiedOutFH;
 use Symbol ('gensym');
 use Carp ();
-
-our $VERSION = '3.33_06';
+use vars qw($VERSION );
+$VERSION = '3.11';
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
@@ -22,7 +20,7 @@ sub handle_on { # some horrible frightening things are encapsulated in here
   ;
   $$x = '' unless defined $$x;
   
-  #Pod::Simple::DEBUG and print STDERR "New $class handle on $x = \"$$x\"\n";
+  #Pod::Simple::DEBUG and print "New $class handle on $x = \"$$x\"\n";
   
   my $new = gensym();
   tie *$new, $class, $x;
@@ -41,7 +39,7 @@ sub PRINT {
   my $it = shift;
   foreach my $x (@_) { $$$it .= $x }
 
-  #Pod::Simple::DEBUG > 10 and print STDERR " appended to $$it = \"$$$it\"\n";
+  #Pod::Simple::DEBUG > 10 and print " appended to $$it = \"$$$it\"\n";
 
   return 1;
 }
