@@ -1,11 +1,8 @@
+
+require 5;
 package Pod::Simple::Transcode;
-
-require 5.006;
-use strict;
-use warnings;
-
-our $VERSION = '3.33_06';
-our @ISA;
+use vars qw($VERSION );
+$VERSION = '3.11';
 
 BEGIN {
   if(defined &DEBUG) {;} # Okay
@@ -19,12 +16,12 @@ foreach my $class (
   '',
 ) {
   $class or die "Couldn't load any encoding classes";
-  DEBUG and print STDERR "About to try loading $class...\n";
+  DEBUG and print "About to try loading $class...\n";
   eval "require $class;";
   if($@) {
-    DEBUG and print STDERR "Couldn't load $class: $@\n";
+    DEBUG and print "Couldn't load $class: $@\n";
   } else {
-    DEBUG and print STDERR "OK, loaded $class.\n";
+    DEBUG and print "OK, loaded $class.\n";
     @ISA = ($class);
     last;
   }
