@@ -1,14 +1,15 @@
-package Pod::Simple::TranscodeSmart;
+
+require 5;
+use 5.008;
+## Anything before 5.8.0 is GIMPY!
 ## This module is to be use()'d only by Pod::Simple::Transcode
 
-## Anything before 5.8.0 is GIMPY!
-use 5.008;
+package Pod::Simple::TranscodeSmart;
 use strict;
-use warnings;
 use Pod::Simple;
 require Encode;
-
-our $VERSION = '3.33_06';
+use vars qw($VERSION );
+$VERSION = '3.11';
 
 sub is_dumb  {0}
 sub is_smart {1}
@@ -26,12 +27,12 @@ sub encmodver {
 }
 
 sub make_transcoder {
-  my $e = Encode::find_encoding($_[1]);
+  my($e) = $_[1];
   die "WHAT ENCODING!?!?" unless $e;
   my $x;
   return sub {
     foreach $x (@_) {
-      $x = $e->decode($x) unless Encode::is_utf8($x);
+      $x = Encode::decode($e, $x);
     }
     return;
   };
