@@ -28,7 +28,7 @@ L<Pod::Simple::HTML>, but it largely preserves the same interface.
 package Pod::Simple::XHTML;
 use strict;
 use vars qw( $VERSION @ISA $HAS_HTML_ENTITIES );
-$VERSION = '3.04';
+$VERSION = '3.11';
 use Carp ();
 use Pod::Simple::Methody ();
 @ISA = ('Pod::Simple::Methody');
@@ -76,6 +76,16 @@ to put before the "Foo%3a%3aBar". The default value is
 What to put after "Foo%3a%3aBar" in the URL. This option is not set by
 default.
 
+=head2 man_url_prefix
+
+In turning C<< L<crontab(5)> >> into http://whatever/man/1/crontab, what
+to put before the "1/crontab". The default value is
+"http://man.he.net/man".
+
+=head2 man_url_postfix
+
+What to put after "1/crontab" in the URL. This option is not set by default.
+
 =head2 title_prefix, title_postfix
 
 What to put before and after the title in the head. The values should
@@ -146,6 +156,8 @@ index for the sake of tradition).
 __PACKAGE__->_accessorize(
  'perldoc_url_prefix',
  'perldoc_url_postfix',
+ 'man_url_prefix',
+ 'man_url_postfix',
  'title_prefix',  'title_postfix',
  'html_css', 
  'html_javascript',
@@ -179,6 +191,7 @@ sub new {
   $new->{'output_fh'} ||= *STDOUT{IO};
   $new->accept_targets( 'html', 'HTML' );
   $new->perldoc_url_prefix('http://search.cpan.org/perldoc?');
+  $new->man_url_prefix('http://man.he.net/man');
   $new->html_header_tags('<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />');
   $new->nix_X_codes(1);
   $new->codes_in_verbatim(1);
@@ -250,14 +263,22 @@ sub start_item_bullet {
 }
 
 sub start_item_text   {
-    $_[0]{'scratch'} = "</dd>\n" if delete $_[0]{'in_dd'};
+    if ($_[0]{'in_dd'}[ $_[0]{'dl_level'} ]) {
+        $_[0]{'scratch'} = "</dd>\n";
+        $_[0]{'in_dd'}[ $_[0]{'dl_level'} ] = 0;
+    }
     $_[0]{'scratch'} .= '<dt>';
 }
 
 sub start_over_bullet { $_[0]{'scratch'} = '<ul>'; $_[0]->emit }
-sub start_over_text   { $_[0]{'scratch'} = '<dl>'; $_[0]->emit }
 sub start_over_block  { $_[0]{'scratch'} = '<ul>'; $_[0]->emit }
 sub start_over_number { $_[0]{'scratch'} = '<ol>'; $_[0]->emit }
+sub start_over_text   {
+    $_[0]{'scratch'} = '<dl>';
+    $_[0]{'dl_level'}++;
+    $_[0]{'in_dd'} ||= [];
+    $_[0]->emit
+}
 
 sub end_over_block  { $_[0]{'scratch'} .= '</ul>'; $_[0]->emit }
 
@@ -274,8 +295,12 @@ sub end_over_bullet   {
 }
 
 sub end_over_text   {
-    $_[0]{'scratch'} = "</dd>\n" if delete $_[0]{'in_dd'};
+    if ($_[0]{'in_dd'}[ $_[0]{'dl_level'} ]) {
+        $_[0]{'scratch'} = "</dd>\n";
+        $_[0]{'in_dd'}[ $_[0]{'dl_level'} ] = 0;
+    }
     $_[0]{'scratch'} .= '</dl>';
+    $_[0]{'dl_level'}--;
     $_[0]->emit;
 }
 
@@ -303,7 +328,12 @@ sub end_head4       { shift->_end_head(@_); }
 
 sub end_item_bullet { $_[0]{'scratch'} .= '</p>'; $_[0]->emit }
 sub end_item_number { $_[0]{'scratch'} .= '</p>'; $_[0]->emit }
-sub end_item_text   { $_[0]{'scratch'} .= "</dt>\n<dd>"; $_[0]{'in_dd'} = 1; $_[0]->emit }
+
+sub end_item_text   {
+    $_[0]{'scratch'} .= "</dt>\n<dd>";
+    $_[0]{'in_dd'}[ $_[0]{'dl_level'} ] = 1;
+    $_[0]->emit;
+}
 
 # This handles =begin and =for blocks of all kinds.
 sub start_for { 
@@ -416,53 +446,24 @@ sub end_B   { $_[0]{'scratch'} .= '</b>' }
 sub start_C { $_[0]{'scratch'} .= '<code>' }
 sub end_C   { $_[0]{'scratch'} .= '</code>' }
 
-sub start_E {
-  my ($self, $flags) = @_;
-  push @{ $self->{'saved'} }, $self->{'scratch'};
-  $self->{'scratch'} = '';
-}
-sub end_E   {
-  my ($self, $flags) = @_;
-  my $previous = pop @{ $self->{'saved'} };
-  my $entity = $self->{'scratch'};
-
-  if ($entity =~ 'sol' or $entity =~ 'verbar') {
-    my $char = Pod::Escapes::e2char($entity);
-    if (defined($char)) {
-      $self->{'scratch'} = $previous . $char;
-      return;
-    }
-  }
-
-  if ($entity =~ /^[0-9]/) {
-      $entity = '#' . $entity;
-  }
-
-  $self->{'scratch'} = $previous . '&'. $entity . ';'
-}
-
 sub start_F { $_[0]{'scratch'} .= '<i>' }
 sub end_F   { $_[0]{'scratch'} .= '</i>' }
 
 sub start_I { $_[0]{'scratch'} .= '<i>' }
 sub end_I   { $_[0]{'scratch'} .= '</i>' }
 
-sub start_L { 
+sub start_L {
   my ($self, $flags) = @_;
-    my $url;
-    if ($flags->{'type'} eq 'url') {
-      $url = $flags->{'to'};
-    } elsif ($flags->{'type'} eq 'pod') {
-      $url .= $self->perldoc_url_prefix || '';
-      $url .= $flags->{'to'} || '';
-      $url .= '/' . $flags->{'section'} if ($flags->{'section'});
-      $url .= $self->perldoc_url_postfix || '';
-#    require Data::Dumper;
-#    print STDERR Data::Dumper->Dump([$flags]);
-    }
+    my ($type, $to, $section) = @{$flags}{'type', 'to', 'section'};
+    my $url = $type eq 'url' ? $to
+            : $type eq 'pod' ? $self->resolve_pod_page_link($to, $section)
+            : $type eq 'man' ? $self->resolve_man_page_link($to, $section)
+            :                  undef;
 
-    $self->{'scratch'} .= '<a href="'. $url . '">';
+    # If it's an unknown type, use an attribute-less <a> like HTML.pm.
+    $self->{'scratch'} .= '<a' . ($url ? ' href="'. $url . '">' : '>');
 }
+
 sub end_L   { $_[0]{'scratch'} .= '</a>' }
 
 sub start_S { $_[0]{'scratch'} .= '<nobr>' }
@@ -479,6 +480,69 @@ sub emit {
   return;
 }
 
+=head2 resolve_pod_page_link
+
+  my $url = $pod->resolve_pod_page_link('Net::Ping', 'INSTALL');
+  my $url = $pod->resolve_pod_page_link('perlpodspec');
+  my $url = $pod->resolve_pod_page_link(undef, 'SYNOPSIS');
+
+Resolves a POD link target (typically a module or POD file name) and section
+name to a URL. The resulting link will be returned for the above examples as:
+
+  http://search.cpan.org/perldoc?Net::Ping#INSTALL
+  http://search.cpan.org/perldoc?perlpodspec
+  #SYNOPSIS
+
+Note that when there is only a section argument the URL will simply be a link
+to a section in the current document.
+
+=cut
+
+sub resolve_pod_page_link {
+    my ($self, $to, $section) = @_;
+    return undef unless defined $to || defined $section;
+    if (defined $section) {
+        $section = '#' . $self->idify($section, 1);
+        return $section unless defined $to;
+    } else {
+        $section = ''
+    }
+
+    return ($self->perldoc_url_prefix || '')
+        . encode_entities($to) . $section
+        . ($self->perldoc_url_postfix || '');
+}
+
+=head2 resolve_man_page_link
+
+  my $url = $pod->resolve_man_page_link('crontab(5)', 'EXAMPLE CRON FILE');
+  my $url = $pod->resolve_man_page_link('crontab');
+
+Resolves a man page link target and numeric section to a URL. The resulting
+link will be returned for the above examples as:
+
+    http://man.he.net/man5/crontab
+    http://man.he.net/man1/crontab
+
+Note that the first argument is required. The section number will be parsed
+from it, and if it's missing will default to 1. The second argument is
+currently ignored, as L<man.he.net|http://man.he.net> does not currently
+include linkable IDs or anchor names in its pages. Subclass to link to a
+different man page HTTP server.
+
+=cut
+
+sub resolve_man_page_link {
+    my ($self, $to, $section) = @_;
+    return undef unless defined $to;
+    my ($page, $part) = $to =~ /^([^(]+)(?:[(](\d+)[)])?$/;
+    return undef unless $page;
+    return ($self->man_url_prefix || '')
+        . ($part || 1) . "/" . encode_entities($page)
+        . ($self->man_url_postfix || '');
+
+}
+
 =head2 idify
 
   my $id   = $pod->idify($text);
@@ -528,9 +592,6 @@ sub idify {
     return "$t$i";
 }
 
-# Bypass built-in E<> handling to preserve entity encoding
-sub _treat_Es {} 
-
 1;
 
 __END__
@@ -539,20 +600,51 @@ __END__
 
 L<Pod::Simple>, L<Pod::Simple::Methody>
 
-=head1 COPYRIGHT
+=head1 SEE ALSO
+
+L<Pod::Simple>, L<Pod::Simple::Text>, L<Pod::Spell>
+
+=head1 SUPPORT
+
+Questions or discussion about POD and Pod::Simple should be sent to the
+pod-people@perl.org mail list. Send an empty email to
+pod-people-subscribe@perl.org to subscribe.
+
+This module is managed in an open GitHub repository,
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
+
+Patches against Pod::Simple are welcome. Please send bug reports to
+<bug-pod-simple@rt.cpan.org>.
+
+=head1 COPYRIGHT AND DISCLAIMERS
 
 Copyright (c) 2003-2005 Allison Randal.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This library is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
-This library is distributed in the hope that it will be useful, but
+This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
 merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Allison Randal <allison@perl.org>
+Pod::Simpele::XHTML was created by Allison Randal <allison@perl.org>.
+
+Pod::Simple was created by Sean M. Burke <sburke@cpan.org>.
+But don't bother him, he's retired.
+
+Pod::Simple is maintained by:
+
+=over
+
+=item * Allison Randal C<allison@perl.org>
+
+=item * Hans Dieter Pearcey C<hdp@cpan.org>
+
+=item * David E. Wheeler C<dwheeler@cpan.org>
+
+=back
 
 =cut
-
