@@ -1,28 +1,25 @@
-package Pod::Simple::XMLOutStream;
 
-require 5.006;
+require 5;
+package Pod::Simple::XMLOutStream;
 use strict;
-use warnings;
 use Carp ();
 use Pod::Simple ();
-
-our $VERSION = '3.33_06';
-our @ISA     = ('Pod::Simple');
-
+use vars qw( $ATTR_PAD @ISA $VERSION $SORT_ATTRS);
+$VERSION = '3.11';
 BEGIN {
+  @ISA = ('Pod::Simple');
   *DEBUG = \&Pod::Simple::DEBUG unless defined &DEBUG;
 }
 
-our $ATTR_PAD = "\n" unless defined $ATTR_PAD;
+$ATTR_PAD = "\n" unless defined $ATTR_PAD;
  # Don't mess with this unless you know what you're doing.
 
-our $SORT_ATTRS = 0 unless defined $SORT_ATTRS;
+$SORT_ATTRS = 0 unless defined $SORT_ATTRS;
 
 sub new {
   my $self = shift;
   my $new = $self->SUPER::new(@_);
   $new->{'output_fh'} ||= *STDOUT{IO};
-  $new->keep_encoding_directive(1);
   #$new->accept_codes('VerbatimFormatted');
   return $new;
 }
@@ -33,7 +30,7 @@ sub _handle_element_start {
   # ($self, $element_name, $attr_hash_r)
   my $fh = $_[0]{'output_fh'};
   my($key, $value);
-  DEBUG and print STDERR "++ $_[1]\n";
+  DEBUG and print "++ $_[1]\n";
   print $fh "<", $_[1];
   if($SORT_ATTRS) {
     foreach my $key (sort keys %{$_[2]}) {
@@ -57,7 +54,7 @@ sub _handle_element_start {
 }
 
 sub _handle_text {
-  DEBUG and print STDERR "== \"$_[1]\"\n";
+  DEBUG and print "== \"$_[1]\"\n";
   if(length $_[1]) {
     my $text = $_[1];
     _xml_escape($text);
@@ -67,7 +64,7 @@ sub _handle_text {
 }
 
 sub _handle_element_end {
-  DEBUG and print STDERR "-- $_[1]\n";
+  DEBUG and print "-- $_[1]\n";
   print {$_[0]{'output_fh'}} "</", $_[1], ">";
   return;
 }
@@ -78,13 +75,11 @@ sub _handle_element_end {
 sub _xml_escape {
   foreach my $x (@_) {
     # Escape things very cautiously:
-    if ($] ge 5.007_003) {
-      $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/'&#'.(utf8::native_to_unicode(ord($1))).';'/eg;
-    } else { # Is broken for non-ASCII platforms on early perls
-      $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/'&#'.(ord($1)).';'/eg;
-    }
+    $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/'&#'.(ord($1)).';'/eg;
     # Yes, stipulate the list without a range, so that this can work right on
     #  all charsets that this module happens to run under.
+    # Altho, hmm, what about that ord?  Presumably that won't work right
+    #  under non-ASCII charsets.  Something should be done about that.
   }
   return;
 }
@@ -129,6 +124,19 @@ The older (and possibly obsolete) libraries L<Pod::PXML>, L<Pod::XML>
 
 TODO: An example or two of =extend, then point to Pod::Simple::Subclassing
 
+
+=head1 ASK ME!
+
+If you actually want to use Pod as a format that you want to render to
+XML (particularly if to an XML instance with more elements than normal
+Pod has), please email me (C<sburke@cpan.org>) and I'll probably have
+some recommendations.
+
+For reasons of concision and energetic laziness, some methods and
+options in this module (and the dozen modules it depends on) are
+undocumented; but one of those undocumented bits might be just what
+you're looking for.
+
 =head1 SEE ALSO
 
 L<Pod::Simple>, L<Pod::Simple::Text>, L<Pod::Spell>
@@ -140,15 +148,15 @@ pod-people@perl.org mail list. Send an empty email to
 pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
-L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+L<http://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
+to clone L<git://github.com/theory/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
 
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002-2004 Sean M. Burke.
+Copyright (c) 2002-2004 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
